@@ -82,7 +82,7 @@ def merge_binary_list(owasp_items, vulnerability_items, bin_list):
 
 
 def get_vulnerability_info(file_with_path, vulnerability, vulnerability_items, remove_vulnerability_items):
-    if vulnerability is not None:
+    if vulnerability:
         try:
             for vul_info in vulnerability:
                 vul_id = ""
@@ -172,7 +172,12 @@ def analyze_jar_file(path_to_find_bin):
                '--disableArchive', '--disableAssembly', '--disableRetireJS', '--disableNodeJS',
                '--disableNodeAudit', '--disableNugetconf', '--disableNuspec', '--disableOpenSSL',
                '--disableOssIndex', '--disableBundleAudit', '--cveValidForHours', '24', '-f', 'JSON']
-    run_analysis(command, dependency_check_run)
+    try:
+        run_analysis(command, dependency_check_run)
+    except Exception as ex:
+        logger.info(f"Error to analyze .jar file - OSS information for .jar file isn't included in report.\n {ex}")
+        success = False
+        return owasp_items, vulnerability_items, success
 
     try:
         json_file = os.path.join(path_to_find_bin, 'dependency-check-report.json')
@@ -195,12 +200,12 @@ def analyze_jar_file(path_to_find_bin):
             oss_license = get_oss_lic_in_jar(val)
             oss_name_found = False
 
-            all_evidence = val.get("evidenceCollected")
-            vulnerability = val.get("vulnerabilityIds")
-            all_pkg_info = val.get("packages")
+            all_evidence = val.get("evidenceCollected", {})
+            vulnerability = val.get("vulnerabilityIds", [])
+            all_pkg_info = val.get("packages", [])
 
-            vendor_evidences = all_evidence.get('vendorEvidence')
-            version_evidences = all_evidence.get('versionEvidence')
+            vendor_evidences = all_evidence.get('vendorEvidence', [])
+            version_evidences = all_evidence.get('versionEvidence', [])
 
             # Check if the file is .jar file
             # Even if the oss info is from pom.xml in jar file, the file name will be .jar file.
